## [1.0.9] - 2023-09-10
### Added
- Edge Object Detection - Functions to save frame when object is detected(Predictive Capture feature)

### Fixed
- Function which draws Detection results over image respective of Mobilent/SSD

## [1.0.8] - 2023-07-30

### Added

- Edge Object detection for SSD and Mobilenet models

### Changed

- Removed CPU object detection
- Test cases

### Fixed

- Fix an dependency issues

### Docs